summaryrefslogtreecommitdiff
path: root/static/resizetest/hump.fm_files
diff options
context:
space:
mode:
authoryo momma <shutup@oops.wtf>2026-02-04 19:04:59 +0000
committeryo momma <shutup@oops.wtf>2026-02-04 19:04:59 +0000
commitad4d74ea45be6b227027588f6515fb22fafc335a (patch)
treedc33e854cc1f6f7d12ca746edef0e844be17f97f /static/resizetest/hump.fm_files
parentae480c44c59a9e77ea279f2208dd7f932079e078 (diff)
Refactor UI: dump classes -> hump
Diffstat (limited to 'static/resizetest/hump.fm_files')
-rwxr-xr-xstatic/resizetest/hump.fm_files/dump.css24
-rwxr-xr-xstatic/resizetest/hump.fm_files/pichat.js42
2 files changed, 33 insertions, 33 deletions
diff --git a/static/resizetest/hump.fm_files/dump.css b/static/resizetest/hump.fm_files/dump.css
index ae021fc..520fa37 100755
--- a/static/resizetest/hump.fm_files/dump.css
+++ b/static/resizetest/hump.fm_files/dump.css
@@ -323,12 +323,12 @@ img.chat-thumb {
}
-.dump .nick {
+.hump .nick {
position: relative;
padding-right: 15px;
}
-.logged-dump {
+.logged-hump {
position: relative;
}
@@ -468,9 +468,9 @@ a.msg-image-zoom img.zoom-icon:hover {
/*div.content img:hover{background-color:white;}*/
.nick{background-color:white;margin-right:3px;}
-.msgDiv dump{background-color:white;}
+.msgDiv.hump{background-color:white;}
.nick a:link{color:#000;margin-right:3px;}
-.msgDiv dump a:link{background-color:white;color:#000;}
+.msgDiv.hump a:link{background-color:white;color:#000;}
/*searchstuff*/
#searchbox{
@@ -1516,7 +1516,7 @@ color:000;
padding-top: 25px;
}
-.logged-dump img{
+.logged-hump img{
max-width:400px;
max-height:400px;
border:0px;
@@ -1528,7 +1528,7 @@ color:000;
}
-.logged-dump {
+.logged-hump {
background-color:#fff;
text-overflow: ellipsis-word;
padding: 18px 18px 6px 18px;
@@ -1592,7 +1592,7 @@ color:#ccc;
margin-bottom:15px;
}
-.logged-dump a:hover {
+.logged-hump a:hover {
text-decoration: none;
color: #00F;
}
@@ -1620,7 +1620,7 @@ z-index:5555;
}
-.dlogged-dump img{
+.dlogged-hump img{
max-width:600px;
width: expression(this.width > 600 ? 600: true);
max-height:600px;
@@ -1630,7 +1630,7 @@ z-index:5555;
}
-.dlogged-dump{
+.dlogged-hump{
min-width:600px;
max-width:600px;
width:600px;
@@ -1877,7 +1877,7 @@ background-color:white;
max-height:70px;
max-width:150px;
}
-.dash-dump {
+.dash-hump {
background-color:#f0f9ff;
text-overflow: ellipsis-word;
padding: 18px 18px 6px 18px;
@@ -1891,13 +1891,13 @@ max-width:150px;
text-align: left;
}
-.dash-dump {
+.dash-hump {
background-color:white;
padding:0px;
display:inline-block;
}
-.dash-dump img{
+.dash-hump img{
background-color:white;
padding:1px;
}
diff --git a/static/resizetest/hump.fm_files/pichat.js b/static/resizetest/hump.fm_files/pichat.js
index 41880a5..03c2cc4 100755
--- a/static/resizetest/hump.fm_files/pichat.js
+++ b/static/resizetest/hump.fm_files/pichat.js
@@ -272,12 +272,12 @@ function setTextEnable() {
TextEnabled = true;
Preferences.setProperty("chat.textEnabled", "true");
track('UI', 'TextEnabled');
- $('.dump').not('.contains-image').show();
+ $('.hump').not('.contains-image').show();
} else {
TextEnabled = false;
Preferences.setProperty("chat.textEnabled", "false");
track('UI', 'TextDisabled');
- $('.dump').not('.contains-image').hide()
+ $('.hump').not('.contains-image').hide()
}
};
@@ -300,7 +300,7 @@ function buildMessageDiv(msg, isLoading) {
var containsImageClass = LastMsgContainsImage ? ' contains-image' : '';
var displayStyle = (TextEnabled || LastMsgContainsImage) ? '' : ' style="display: none"';
- return '<div class="msgDiv dump ' + loadingClass + containsImageClass + '" ' + msgId + displayStyle + '>'
+ return '<div class="msgDiv hump ' + loadingClass + containsImageClass + '" ' + msgId + displayStyle + '>'
+ '<span class="nick"><b><a href="/' + nick + ' ">' + nick + '</a></b>'
+ ' <img src="'+Imgs.chatThumbDot+'" class="chat-thumb" onclick="Tag.favorite(this)"> '
+ '</span>'
@@ -565,14 +565,14 @@ function initChat() {
Search.init()
$('.oldmsg').each(function() {
- var dump = $(this);
- var content = dump.find(".content")
- MessageContentCache[dump.attr("id").substr(8)] = content.text()
+ var hump = $(this);
+ var content = hump.find(".content")
+ MessageContentCache[hump.attr("id").substr(8)] = content.text()
content.html(buildMsgContent(content.text()));
- if (!TextEnabled && !dump.hasClass('contains-image'))
- dump.hide();
+ if (!TextEnabled && !hump.hasClass('contains-image'))
+ hump.hide();
else
- dump.show();
+ hump.show();
});
$('#msgInput').keyup(ifEnter(submitMessage));
@@ -653,7 +653,7 @@ function initProfile() {
$('#edit-toggle').click(enableProfileEdit);
activateProfileEditable();
- $('.dash-dump .content').each(function() {
+ $('.dash-hump .content').each(function() {
var t = $(this);
t.html(buildMsgContent(t.text()));
});
@@ -661,11 +661,11 @@ function initProfile() {
function initLog() {
Search.init()
- $('.logged-dump .content').each(function() {
+ $('.logged-hump .content').each(function() {
var t = $(this);
t.html(buildMsgContent(t.text()));
});
- initLogThumb(".logged-dump .thumb", '.dump');
+ initLogThumb(".logged-hump .thumb", '.hump');
}
function initLogThumb(selector, parentSelector) {
@@ -694,7 +694,7 @@ function initLogThumb(selector, parentSelector) {
function initChatThumb(){
$(".chat-thumb").live('mouseover mouseout',
function(e) {
- var favorited = $(this).parents(".dump").hasClass("favorite") ? true : false;
+ var favorited = $(this).parents(".hump").hasClass("favorite") ? true : false;
if (e.type == "mouseover") {
if (favorited) {
$(this).attr("src", Imgs.chatThumbOff);
@@ -1066,7 +1066,7 @@ function initDirectory() {
t.html(buildMsgContent(t.text()));
});
Search.init()
- initLogThumb('.dlogged-dump .thumb', '.dlogged-dump');
+ initLogThumb('.dlogged-hump .thumb', '.dlogged-hump');
}
//big hand stuff
@@ -1136,10 +1136,10 @@ function initBigHand(id){
}
// grab message id etc from some element e that's inside a dump
// (messages have something like id="message-0001" class="dump" )
function getMessageInfo(e){
- var message = $(e).parents(".dump")
+ var message = $(e).parents(".hump")
var id = message.attr("id").substr(8) // cut "message-001" to "001"
var nick = message.attr("nick")
var link = "/p/" + nick + "/" + id
@@ -1182,17 +1182,17 @@ Share = {
Tag = {
"favorite": function(button){
var message = getMessageInfo(button)
- var favorited = ($(button).parents(".dump").hasClass("favorite")) ? true : false
+ var favorited = ($(button).parents(".hump").hasClass("favorite")) ? true : false
if (favorited) {
Tag.rm(message.id, "favorite")
- $(button).parents(".dump").removeClass("favorite")
+ $(button).parents(".hump").removeClass("favorite")
if (RawFavs[message.id]) {
delete RawFavs[message.id]
paletteImageCache = false
}
} else {
Tag.add(message.id, "favorite")
- $(button).parents(".dump").addClass("favorite")
+ $(button).parents(".hump").addClass("favorite")
if (RawFavs && MessageContentCache[message.id]) { // chat ui stuff
if ($("#palette-button").css("display") == "none")
paletteButtonShowAnim()
@@ -1307,7 +1307,7 @@ var Away = {
"updateTitle": function () {
if (Away.UnseenMsgCounter > 0) {
var plural = Away.UnseenMsgCounter > 1 ? 's' : '';
- $('title').text(Away.UnseenMsgCounter + ' new dump' + plural + '! | ' + Away.OrigTitle);
+ $('title').text(Away.UnseenMsgCounter + ' new hump' + plural + '! | ' + Away.OrigTitle);
}
setTimeout(Away.updateTitle, Away.UpdateFrequency);
@@ -1136,10 +1136,10 @@ function initBigHand(id){
}
-// grab message id etc from some element e that's inside a dump
-// (messages have something like id="message-0001" class="dump" )
+// grab message id etc from some element e that's inside a hump
+// (messages have something like id="message-0001" class="hump" )
function getMessageInfo(e){